==> viha-5.15.tar.gz: viha-5.15/tap.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "tap";
$file = basename(__FILE__);

include "common.php";
include "tap-ok.php";

echo "
<html>
<head>
 <title>VIHA - Tapahtumakirjaus</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", tapahtuman kirjaus</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$ryhma_id = get_nro_1('ryhma_id');
$tap = get_txt('tap');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = tap_add_ok($herja,s('alue'),
		    s('paivystys'),
		    $ryhma_id,$tap);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           ryhma_id = $ryhma_id,
           tap = '$tap',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
    taktinen_loki(ota_kutsu($ryhma_id) . ": $tap");
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = tap_save_ok($herja,$id,s('alue'),
		     s('paivystys'),
		     $ryhma_id,$tap);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           ryhma_id=$ryhma_id,
           tap='$tap',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
    loki("Tapahtumakirjausta muutettu, id=$id");
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = tap_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
    loki($sql);
    loki("Tapahtumakirjaus poistettu, id=$id");
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $ryhma_id = "1";
    $tap = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = tap_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $ryhma_id = $a['ryhma_id'];
  $tap = $a['tap']; 
}		  
echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Ryhm:";
if ($readonly) {
  echo "<td>" . tab_col_id("ryhma","kutsu",$ryhma_id);
} else {
  echo "<td>\n";
  select_ryhma($ryhma_id);
}

echo "<tr><td>Tapahtuma:";
if ($readonly) {
  echo "<td>$tap\n";
} else {
  echo "<td><input type=\"text\" name=\"tap\" size=64 maxlength=255";
  echo " value=\"$tap\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result =
  my_mysql_query("SELECT $table.id,$table.ts,ryhma.kutsu,$table.tap
                  FROM $table,ryhma
                  WHERE $table.ryhma_id = ryhma.id
                  ORDER BY $table.id");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Ryhm<TH>Tapahtuma\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo "<TR><TD>$a[id]",
      "<TD>$a[ts]", 
      "<TD>$a[kutsu]", 
      "<TD>$a[tap]";
    if ($id == "0") {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei tapahtumatietoja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: tap.php,v 1.12 2009/04/18 16:06:56 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/tap.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "tap";
$file = basename(__FILE__);

include "common.php";
include "tap-ok.php";

echo "
<html>
<head>
 <title>VIHA - Tapahtumakirjaus</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", tapahtuman kirjaus</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$ryhma_id = get_nro_1('ryhma_id');
$tap = get_txt('tap');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = tap_add_ok($herja,s('alue'),
		    s('paivystys'),
		    $ryhma_id,$tap);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           ryhma_id = $ryhma_id,
           tap = '$tap',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
    taktinen_loki(ota_kutsu($ryhma_id) . ": $tap");
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = tap_save_ok($herja,$id,s('alue'),
		     s('paivystys'),
		     $ryhma_id,$tap);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           ryhma_id=$ryhma_id,
           tap='$tap',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
    loki("Tapahtumakirjausta muutettu, id=$id");
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = tap_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
    loki($sql);
    loki("Tapahtumakirjaus poistettu, id=$id");
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $ryhma_id = "1";
    $tap = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = tap_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $ryhma_id = $a['ryhma_id'];
  $tap = $a['tap']; 
}		  
echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Ryhm:";
if ($readonly) {
  echo "<td>" . tab_col_id("ryhma","kutsu",$ryhma_id);
} else {
  echo "<td>\n";
  select_ryhma($ryhma_id);
}

echo "<tr><td>Tapahtuma:";
if ($readonly) {
  echo "<td>$tap\n";
} else {
  echo "<td><input type=\"text\" name=\"tap\" size=64 maxlength=255";
  echo " value=\"$tap\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result =
  my_mysql_query("SELECT $table.id,$table.ts,ryhma.kutsu,$table.tap
                  FROM $table,ryhma
                  WHERE $table.ryhma_id = ryhma.id
                  ORDER BY $table.id");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Ryhm<TH>Tapahtuma\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo tr() . "<TD>$a[id]",
      "<TD>$a[ts]", 
      "<TD>$a[kutsu]", 
      "<TD>$a[tap]";
    if ($id == "0") {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei tapahtumatietoja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: tap.php,v 1.14 2009/09/29 16:09:15 riku Exp $ -->
